#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-golden
version:              2.3.6
visibility:           public
id:                   tasty-golden-2.3.6-H3sPQveDVb6HzV7coiddYm
key:                  tasty-golden-2.3.6-H3sPQveDVb6HzV7coiddYm
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/UnkindPartition/tasty-golden
synopsis:             Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.

category:             Testing
abi:                  8e180445ecff4fc8c7d06d5ba484fc1b
exposed:              True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage

hidden-modules:       Test.Tasty.Golden.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-golden-2.3.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-golden-2.3.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-golden-2.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-golden
hs-libraries:         HStasty-golden-2.3.6-H3sPQveDVb6HzV7coiddYm
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.300.1
    optparse-applicative-0.18.1.0-2OPlFtvlr5yI8qFRB5F8bn
    tasty-1.5.3-9Ly5zOHTOKj1qAbC4RsUQH
    temporary-1.3-6jR9Y0qK20e3lOLKCzgpYi text-2.0.2
    typed-process-0.2.13.0-8swOl8qwZIo4tYHRa44umx

haddock-interfaces:
    /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock

haddock-html:         /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

